@@ -13,9 +13,9 @@ from requests.packages.urllib3 import Retry
 from requests.adapters import HTTPAdapter
 from time import time
 
-from common import server_error, raise_errors
+from .common import server_error, raise_errors
 
-from media import file_creation_time
+from .media import file_creation_time
 
 IP_REGEX = re.compile('^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$')
 
